@@ -6,26 +6,24 @@ This is an internal API not covered by versioning policy.
 """
 import re
 import traceback
+import typing as t
 from collections.abc import Mapping, Sequence
-from re import Pattern
-from typing import TYPE_CHECKING, Any, Callable, List, Optional, TypeVar, Union
 
-if TYPE_CHECKING:
-    from typing_extensions import Protocol
+if t.TYPE_CHECKING:
 
-    class LookupProtocol(Protocol):
+    class LookupProtocol(t.Protocol):
         """Protocol for :class:`QueryList` filtering operators."""
 
         def __call__(
             self,
-            data: Union[str, List[str], "Mapping[str, str]"],
-            rhs: Union[str, List[str], "Mapping[str, str]", "Pattern[str]"],
+            data: t.Union[str, t.List[str], "Mapping[str, str]"],
+            rhs: t.Union[str, t.List[str], "Mapping[str, str]", "re.Pattern[str]"],
         ) -> bool:
             """Callback for :class:`QueryList` filtering operators."""
             ...
 
 
-T = TypeVar("T", Any, Any)
+T = t.TypeVar("T", t.Any, t.Any)
 
 no_arg = object()
 
@@ -39,9 +37,9 @@ class ObjectDoesNotExist(Exception):
 
 
 def keygetter(
-    obj: "Mapping[str, Any]",
+    obj: "Mapping[str, t.Any]",
     path: str,
-) -> Union[None, Any, str, List[str], "Mapping[str, str]"]:
+) -> t.Union[None, t.Any, str, t.List[str], "Mapping[str, str]"]:
     """obj, "foods__breakfast", obj['foods']['breakfast']
 
     >>> keygetter({ "foods": { "breakfast": "cereal" } }, "foods__breakfast")
@@ -67,7 +65,9 @@ def keygetter(
     return dct
 
 
-def parse_lookup(obj: "Mapping[str, Any]", path: str, lookup: str) -> Optional[Any]:
+def parse_lookup(
+    obj: "Mapping[str, t.Any]", path: str, lookup: str
+) -> t.Optional[t.Any]:
     """Check if field lookup key, e.g. "my__path__contains" has comparator, return val.
 
     If comparator not used or value not found, return None.
@@ -88,15 +88,15 @@ def parse_lookup(obj: "Mapping[str, Any]", path: str, lookup: str) -> Optional[A
 
 
 def lookup_exact(
-    data: Union[str, List[str], "Mapping[str, str]"],
-    rhs: Union[str, List[str], "Mapping[str, str]", "Pattern[str]"],
+    data: t.Union[str, t.List[str], "Mapping[str, str]"],
+    rhs: t.Union[str, t.List[str], "Mapping[str, str]", "re.Pattern[str]"],
 ) -> bool:
     return rhs == data
 
 
 def lookup_iexact(
-    data: Union[str, List[str], "Mapping[str, str]"],
-    rhs: Union[str, List[str], "Mapping[str, str]", "Pattern[str]"],
+    data: t.Union[str, t.List[str], "Mapping[str, str]"],
+    rhs: t.Union[str, t.List[str], "Mapping[str, str]", "re.Pattern[str]"],
 ) -> bool:
     if not isinstance(rhs, str) or not isinstance(data, str):
         return False
@@ -105,8 +105,8 @@ def lookup_iexact(
 
 
 def lookup_contains(
-    data: Union[str, List[str], "Mapping[str, str]"],
-    rhs: Union[str, List[str], "Mapping[str, str]", "Pattern[str]"],
+    data: t.Union[str, t.List[str], "Mapping[str, str]"],
+    rhs: t.Union[str, t.List[str], "Mapping[str, str]", "re.Pattern[str]"],
 ) -> bool:
     if not isinstance(rhs, str) or not isinstance(data, (str, Mapping, list)):
         return False
@@ -115,8 +115,8 @@ def lookup_contains(
 
 
 def lookup_icontains(
-    data: Union[str, List[str], "Mapping[str, str]"],
-    rhs: Union[str, List[str], "Mapping[str, str]", "Pattern[str]"],
+    data: t.Union[str, t.List[str], "Mapping[str, str]"],
+    rhs: t.Union[str, t.List[str], "Mapping[str, str]", "re.Pattern[str]"],
 ) -> bool:
     if not isinstance(rhs, str) or not isinstance(data, (str, Mapping, list)):
         return False
@@ -130,8 +130,8 @@ def lookup_icontains(
 
 
 def lookup_startswith(
-    data: Union[str, List[str], "Mapping[str, str]"],
-    rhs: Union[str, List[str], "Mapping[str, str]", "Pattern[str]"],
+    data: t.Union[str, t.List[str], "Mapping[str, str]"],
+    rhs: t.Union[str, t.List[str], "Mapping[str, str]", "re.Pattern[str]"],
 ) -> bool:
     if not isinstance(rhs, str) or not isinstance(data, str):
         return False
@@ -140,8 +140,8 @@ def lookup_startswith(
 
 
 def lookup_istartswith(
-    data: Union[str, List[str], "Mapping[str, str]"],
-    rhs: Union[str, List[str], "Mapping[str, str]", "Pattern[str]"],
+    data: t.Union[str, t.List[str], "Mapping[str, str]"],
+    rhs: t.Union[str, t.List[str], "Mapping[str, str]", "re.Pattern[str]"],
 ) -> bool:
     if not isinstance(rhs, str) or not isinstance(data, str):
         return False
@@ -150,8 +150,8 @@ def lookup_istartswith(
 
 
 def lookup_endswith(
-    data: Union[str, List[str], "Mapping[str, str]"],
-    rhs: Union[str, List[str], "Mapping[str, str]", "Pattern[str]"],
+    data: t.Union[str, t.List[str], "Mapping[str, str]"],
+    rhs: t.Union[str, t.List[str], "Mapping[str, str]", "re.Pattern[str]"],
 ) -> bool:
     if not isinstance(rhs, str) or not isinstance(data, str):
         return False
@@ -160,8 +160,8 @@ def lookup_endswith(
 
 
 def lookup_iendswith(
-    data: Union[str, List[str], "Mapping[str, str]"],
-    rhs: Union[str, List[str], "Mapping[str, str]", "Pattern[str]"],
+    data: t.Union[str, t.List[str], "Mapping[str, str]"],
+    rhs: t.Union[str, t.List[str], "Mapping[str, str]", "re.Pattern[str]"],
 ) -> bool:
     if not isinstance(rhs, str) or not isinstance(data, str):
         return False
@@ -169,8 +169,8 @@ def lookup_iendswith(
 
 
 def lookup_in(
-    data: Union[str, List[str], "Mapping[str, str]"],
-    rhs: Union[str, List[str], "Mapping[str, str]", "Pattern[str]"],
+    data: t.Union[str, t.List[str], "Mapping[str, str]"],
+    rhs: t.Union[str, t.List[str], "Mapping[str, str]", "re.Pattern[str]"],
 ) -> bool:
     if isinstance(rhs, list):
         return data in rhs
@@ -191,8 +191,8 @@ def lookup_in(
 
 
 def lookup_nin(
-    data: Union[str, List[str], "Mapping[str, str]"],
-    rhs: Union[str, List[str], "Mapping[str, str]", "Pattern[str]"],
+    data: t.Union[str, t.List[str], "Mapping[str, str]"],
+    rhs: t.Union[str, t.List[str], "Mapping[str, str]", "re.Pattern[str]"],
 ) -> bool:
     if isinstance(rhs, list):
         return data not in rhs
@@ -213,8 +213,8 @@ def lookup_nin(
 
 
 def lookup_regex(
-    data: Union[str, List[str], "Mapping[str, str]"],
-    rhs: Union[str, List[str], "Mapping[str, str]", "Pattern[str]"],
+    data: t.Union[str, t.List[str], "Mapping[str, str]"],
+    rhs: t.Union[str, t.List[str], "Mapping[str, str]", "re.Pattern[str]"],
 ) -> bool:
     if isinstance(data, (str, bytes, re.Pattern)) and isinstance(rhs, (str, bytes)):
         return bool(re.search(rhs, data))
@@ -222,8 +222,8 @@ def lookup_regex(
 
 
 def lookup_iregex(
-    data: Union[str, List[str], "Mapping[str, str]"],
-    rhs: Union[str, List[str], "Mapping[str, str]", "Pattern[str]"],
+    data: t.Union[str, t.List[str], "Mapping[str, str]"],
+    rhs: t.Union[str, t.List[str], "Mapping[str, str]", "re.Pattern[str]"],
 ) -> bool:
     if isinstance(data, (str, bytes, re.Pattern)) and isinstance(rhs, (str, bytes)):
         return bool(re.search(rhs, data, re.IGNORECASE))
@@ -257,7 +257,7 @@ class OpNotFound(ValueError):
         return super().__init__(f"{op} not in LOOKUP_NAME_MAP")
 
 
-class QueryList(List[T]):
+class QueryList(t.List[T]):
     """Filter list of object/dictionaries. For small, local datasets.
 
     *Experimental, unstable*.
@@ -293,9 +293,9 @@ class QueryList(List[T]):
     """
 
     data: "Sequence[T]"
-    pk_key: Optional[str]
+    pk_key: t.Optional[str]
 
-    def items(self) -> List[T]:
+    def items(self) -> t.List[T]:
         if self.pk_key is None:
             raise PKRequiredException()
         return [(getattr(item, self.pk_key), item) for item in self]
@@ -303,11 +303,11 @@ class QueryList(List[T]):
     def __eq__(
         self,
         other: object,
-        # other: Union[
+        # other: t.Union[
         #     "QueryList[T]",
-        #     List[Mapping[str, str]],
-        #     List[Mapping[str, int]],
-        #     List[Mapping[str, Union[str, Mapping[str, Union[List[str], str]]]]],
+        #     t.List[Mapping[str, str]],
+        #     t.List[Mapping[str, int]],
+        #     t.List[Mapping[str, t.Union[str, Mapping[str, t.Union[List[str], str]]]]],
         # ],
     ) -> bool:
         data = other
@@ -331,11 +331,13 @@ class QueryList(List[T]):
         return False
 
     def filter(
-        self, matcher: Optional[Union[Callable[[T], bool], T]] = None, **kwargs: Any
+        self,
+        matcher: t.Optional[t.Union[t.Callable[[T], bool], T]] = None,
+        **kwargs: t.Any,
     ) -> "QueryList[T]":
         """Filter list of objects."""
 
-        def filter_lookup(obj: Any) -> bool:
+        def filter_lookup(obj: t.Any) -> bool:
             for path, v in kwargs.items():
                 try:
                     lhs, op = path.rsplit("__", 1)
@@ -359,7 +361,7 @@ class QueryList(List[T]):
             _filter = matcher
         elif matcher is not None:
 
-            def val_match(obj: Union[str, List[Any]]) -> bool:
+            def val_match(obj: t.Union[str, t.List[t.Any]]) -> bool:
                 if isinstance(matcher, list):
                     return obj in matcher
                 else:
@@ -373,10 +375,10 @@ class QueryList(List[T]):
 
     def get(
         self,
-        matcher: Optional[Union[Callable[[T], bool], T]] = None,
-        default: Optional[Any] = no_arg,
-        **kwargs: Any,
-    ) -> Optional[T]:
+        matcher: t.Optional[t.Union[t.Callable[[T], bool], T]] = None,
+        default: t.Optional[t.Any] = no_arg,
+        **kwargs: t.Any,
+    ) -> t.Optional[T]:
         """Retrieve one object.
 
         Raises :exc:`MultipleObjectsReturned` if multiple objects found.
